@@ -9,12 +9,15 @@
 
 
 import os
+import pkg_resources
 from six.moves.configparser import ConfigParser
 from appdirs import user_config_dir
 
 
 class IoTNodeConfig(object):
     _appname = 'iotnode'
+    _root = os.path.abspath(os.path.dirname(__file__))
+    _roots = [_root]
     _config_file = os.path.join(user_config_dir(_appname), 'config.ini')
     _sys_config_file = os.path.join('/etc/raspap/custom.ini')
 
@@ -26,6 +29,11 @@ class IoTNodeConfig(object):
         print("Reading System Config File {}".format(self._sys_config_file))
         self._sys_config.read(self._sys_config_file)
         self._config_apply_init()
+        print("EBS IOT Linux Node, version {0}".format(self.linuxnode_version))
+
+    @property
+    def linuxnode_version(self):
+        return pkg_resources.get_distribution('ebs-iot-linuxnode').version
 
     def _config_apply_init(self):
         self._apply_display_layer()
@@ -34,6 +42,30 @@ class IoTNodeConfig(object):
         with open(self._config_file, 'w') as configfile:
             self._config.write(configfile)
 
+    def _check_section(self, section):
+        if not self._config.has_section(section):
+            self._config.add_section(section)
+            self._write_config()
+
+    # Paths
+    @property
+    def app_root(self):
+        return self._root
+
+    @property
+    def app_resources(self):
+        return os.path.join(self.app_root, 'resources')
+
+    @property
+    def roots(self):
+        return self._roots
+
+    def get_path(self, filepath):
+        for root in self._roots:
+            if os.path.exists(os.path.join(root, filepath)):
+                return os.path.join(root, filepath)
+        return filepath
+
     # Platform
     @property
     def platform(self):
@@ -83,6 +115,7 @@ class IoTNodeConfig(object):
 
     @background.setter
     def background(self, value):
+        self._check_section('display')
         self._config.set('display', 'background', value)
         self._write_config()
 
@@ -222,6 +255,7 @@ class IoTNodeConfig(object):
 
     @browser_show_default.setter
     def browser_show_default(self, value):
+        self._check_section('browser')
         if value:
             value = 'yes'
         else:
@@ -235,31 +269,26 @@ class IoTNodeConfig(object):
 
     @browser_default_url.setter
     def browser_default_url(self, value):
+        self._check_section('browser')
         self._config.set('browser', 'default_url', value)
         self._write_config()
 
     # Fonts
     @property
     def text_font_name(self):
-        font_name = self._config.get('text', 'font_name', fallback=None)
-        return font_name
-
-    # API
+        return self.get_path(self._config.get('text', 'font_name', fallback=None)
+)
     @property
-    def api_url(self):
-        return self._config.get('api', 'url', fallback=None)
-
+    def text_use_fcm(self):
+        return self._config.getboolean('text', 'use_fcm', fallback=False)
+    
     @property
-    def api_token(self):
-        return self._config.get('api', 'token', fallback=None)
-
-    @api_token.setter
-    def api_token(self, value):
-        if not value:
-            self._config.remove_option('api', 'token')
-        else:
-            self._config.set('api', 'token', value)
-        self._write_config()
+    def text_fcm_system(self):
+        return self._config.getboolean('text', 'fcm_system', fallback=True)
+    
+    @property
+    def text_fcm_fonts(self):
+        return self.get_path(self._config.get('text', 'fcm_fonts', fallback=None))
 
 
 class ConfigMixin(object):
@@ -269,5 +298,5 @@ class ConfigMixin(object):
         super(ConfigMixin, self).__init__(*args, **kwargs)
 
     @property
-    def config(self):
+    def config(self) -> IoTNodeConfig:
         return self._config
