@@ -25,13 +25,12 @@ from .mediaplayer import MediaPlayerBusy
 from .marquee import MarqueeBusy
 from .widgets.pdfplayer import generate_pdf_images
 
+from .constants import WEBRESOURCE
+from .constants import TEXT
 
 Base = declarative_base()
 metadata = Base.metadata
 
-WEBRESOURCE = 1
-TEXT = 2
-
 
 class WebResourceEventsModel(Base):
     __tablename__ = 'events_1'
@@ -546,6 +545,7 @@ class WebResourceEventManager(EventManager):
 class EventManagerMixin(BaseIoTNode):
     def __init__(self, *args, **kwargs):
         self._event_managers = {}
+        self._success_api_engine = None
         super(EventManagerMixin, self).__init__(*args, **kwargs)
 
     def event_manager_install(self, manager):
@@ -563,10 +563,14 @@ class EventManagerMixin(BaseIoTNode):
             return []
 
     def api_media_success(self, events):
-        raise NotImplementedError
+        if not self._success_api_engine:
+            raise NotImplementedError
+        self._success_api_engine.api_media_success(events)
 
     def api_text_success(self, events):
-        raise NotImplementedError
+        if not self._success_api_engine:
+            raise NotImplementedError
+        self._success_api_engine.api_text_success(events)
 
     def start(self):
         super(EventManagerMixin, self).start()
