@@ -39,7 +39,8 @@ class BasicTablePalette(object):
 
 
 class BasicColumnSpec(object):
-    def __init__(self, title, accessor, halign=None, font_bold=None, width=None, width_hint=None):
+    def __init__(self, title, accessor, halign=None, font_bold=None,
+                 width=None, width_hint=None, markup=False):
         self._parent = None
         self._title = title
         self._accessor = accessor
@@ -47,6 +48,7 @@ class BasicColumnSpec(object):
         self._font_bold = font_bold
         self._width = width
         self._width_hint = width_hint
+        self._markup = markup
 
     @property
     def parent(self):
@@ -84,11 +86,17 @@ class BasicColumnSpec(object):
             return None
         return self._width_hint or 1
 
+    @property
+    def markup(self):
+        return self._markup
+
 
 class BasicTableSpec(object):
-    def __init__(self, column_specs, show_column_header, dedup_keys=False,
-                 row_height=90, row_spacing=10, font_size='42sp',
-                 font_bold=False, font_name=None):
+    def __init__(self, parent, column_specs, name='UNK', show_column_header=True,
+                 dedup_keys=False, row_height=90, row_spacing=10,
+                 font_size='42sp', font_bold=False, font_name=None, font_context=None):
+        self._name = name
+        self._parent = parent
         self._column_specs = column_specs
         for colspec in self._column_specs:
             colspec.parent = self
@@ -99,11 +107,27 @@ class BasicTableSpec(object):
         self._font_bold = font_bold
         self._dedup_keys = dedup_keys
         self._font_name = font_name
+        self._font_context = font_context
+
+    def install(self):
+        pass
+
+    @property
+    def name(self):
+        return self._name
+
+    @property
+    def parent(self):
+        return self._parent
 
     @property
     def font_name(self):
         return self._font_name
 
+    @property
+    def font_context(self):
+        return self._font_context
+
     @property
     def font_size(self):
         return self._font_size
@@ -112,6 +136,16 @@ class BasicTableSpec(object):
     def font_bold(self):
         return self._font_bold
 
+    @property
+    def font_params(self):
+        params = {
+            'font_context': self.font_context,
+            'font_name': self.font_name,
+            'font_size': self.font_size,
+            'bold': self.font_bold,
+        }
+        return {k: v for k, v in params.items() if v is not None}
+
     @property
     def show_column_header(self) -> bool:
         return self._show_column_header
